@@ -16,43 +16,50 @@
 """
 libcloud provides a unified interface to the cloud computing resources.
 
-@var __version__: Current version of libcloud
+:var __version__: Current version of libcloud
 """
 
-__all__ = ["__version__", "enable_debug"]
+__all__ = ['__version__', 'enable_debug']
+__version__ = '0.15.1'
+
+import os
+
+try:
+    import paramiko
+    have_paramiko = True
+except ImportError:
+    have_paramiko = False
 
-__version__ = "0.5.0"
 
 def enable_debug(fo):
     """
     Enable library wide debugging to a file-like object.
 
-    @param fo: Where to append debugging information
-    @type fo: File like object, only write operations are used.
+    :param fo: Where to append debugging information
+    :type fo: File like object, only write operations are used.
     """
-    from libcloud.base import (ConnectionKey,
-                               LoggingHTTPConnection,
-                               LoggingHTTPSConnection)
+    from libcloud.common.base import (Connection,
+                                      LoggingHTTPConnection,
+                                      LoggingHTTPSConnection)
     LoggingHTTPSConnection.log = fo
     LoggingHTTPConnection.log = fo
-    ConnectionKey.conn_classes = (LoggingHTTPConnection, LoggingHTTPSConnection)
+    Connection.conn_classes = (LoggingHTTPConnection,
+                               LoggingHTTPSConnection)
+
 
 def _init_once():
     """
     Utility function that is ran once on Library import.
 
-    This checks for the LIBCLOUD_DEBUG enviroment variable, which if it exists
+    This checks for the LIBCLOUD_DEBUG environment variable, which if it exists
     is where we will log debug information about the provider transports.
-
-    If LIBCLOUD_DEBUG is not a path, C{/tmp/libcloud_debug.log} is used by
-    default.
     """
-    import os
-    d = os.getenv("LIBCLOUD_DEBUG")
-    if d:
-        if d.isdigit():
-            d = "/tmp/libcloud_debug.log"
-        fo = open(d, "a")
+    path = os.getenv('LIBCLOUD_DEBUG')
+    if path:
+        fo = open(path, 'a')
         enable_debug(fo)
 
+        if have_paramiko:
+            paramiko.common.logging.basicConfig(level=paramiko.common.DEBUG)
+
 _init_once()
