@@ -18,20 +18,23 @@ Drivers for working with different providers
 """
 
 __all__ = [
+    'abiquo',
     'brightbox',
     'bluebox',
     'dummy',
     'ec2',
     'ecp',
+    'elasticstack',
     'elastichosts',
     'cloudsigma',
+    'gce',
     'gogrid',
-    'ibm_sbc',
+    'hostvirtual',
+    'ibm_sce',
     'linode',
     'opennebula',
     'rackspace',
     'rimuhosting',
-    'slicehost',
     'softlayer',
     'vcloud',
     'voxel',
