@@ -14,30 +14,57 @@
 # limitations under the License.
 
 __all__ = [
-        "Provider",
-        "State",
-        "LibcloudLBError",
-        "LibcloudLBImmutableError",
-        ]
+    "Provider",
+    "State",
+    "LibcloudLBError",
+    "LibcloudLBImmutableError",
+]
 
 from libcloud.common.types import LibcloudError
 
-class LibcloudLBError(LibcloudError): pass
 
-class LibcloudLBImmutableError(LibcloudLBError): pass
+class LibcloudLBError(LibcloudError):
+    pass
+
+
+class LibcloudLBImmutableError(LibcloudLBError):
+    pass
+
 
 class Provider(object):
-    RACKSPACE_US = 0
-    GOGRID = 1
+    RACKSPACE = 'rackspace'
+    GOGRID = 'gogrid'
+    NINEFOLD = 'ninefold'
+    BRIGHTBOX = 'brightbox'
+    ELB = 'elb'
+    CLOUDSTACK = 'cloudstack'
+    GCE = 'gce'
+
+    # Deprecated
+    RACKSPACE_US = 'rackspace_us'
+    RACKSPACE_UK = 'rackspace_uk'
+
 
 class State(object):
     """
-    Standart states for a loadbalancer
+    Standard states for a loadbalancer
 
-    @cvar RUNNING: loadbalancer is running and ready to use
-    @cvar UNKNOWN: loabalancer state is unknown
+    :cvar RUNNING: loadbalancer is running and ready to use
+    :cvar UNKNOWN: loabalancer state is unknown
     """
 
     RUNNING = 0
     PENDING = 1
     UNKNOWN = 2
+    ERROR = 3
+    DELETED = 4
+
+
+class MemberCondition(object):
+    """
+    Each member of a load balancer can have an associated condition
+    which determines its role within the load balancer.
+    """
+    ENABLED = 0
+    DISABLED = 1
+    DRAINING = 2
